==> ejc-middlemeasurement-impl-3.0.0-20220412.090131-33-sources.jar: com/ejianc/business/middlemeasurement/bean/InterimsettlementdetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目期中结算台账子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_interimsettlementdetail")
public class InterimsettlementdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="Issue_number")
    private java.lang.String issueNumber; // 期号
    @TableField(value="completion_month")
    private java.lang.String completionMonth; // 完成工程款月份
    @TableField(value="application_no")
    private java.lang.String applicationNo; // 申请单编号
    @TableField(value="application_amount")
    private java.math.BigDecimal applicationAmount; // 申请金额(元)
    @TableField(value="current_approval")
    private java.math.BigDecimal currentApproval; // 本期
    @TableField(value="cumulative_approval")
    private java.math.BigDecimal cumulativeApproval; // 累计
    @TableField(value="income")
    private java.math.BigDecimal income; // 财务列报收入
    @TableField(value="current_receivable")
    private java.math.BigDecimal currentReceivable; // 本期
    @TableField(value="cumulative_receivable")
    private java.math.BigDecimal cumulativeReceivable; // 累计
    @TableField(value="current_retention")
    private java.math.BigDecimal currentRetention; // 本期
    @TableField(value="cumulative_retention")
    private java.math.BigDecimal cumulativeRetention; // 累计
    @TableField(value="current_actual")
    private java.math.BigDecimal currentActual; // 本期
    @TableField(value="cumulative_actual")
    private java.math.BigDecimal cumulativeActual; // 累计
    @TableField(value="current_uncollected")
    private java.math.BigDecimal currentUncollected; // 本期
    @TableField(value="cumulative_uncollected")
    private java.math.BigDecimal cumulativeUncollected; // 累计
    @TableField(value="actual_collection")
    private java.util.Date actualCollection; // 实际收款日期
    @TableField(value="cash_flow")
    private java.lang.String cashFlow; // 现金流
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注


    public BigDecimal getCurrentReceivable() {
        return currentReceivable;
    }

    public void setCurrentReceivable(BigDecimal currentReceivable) {
        this.currentReceivable = currentReceivable;
    }

    public BigDecimal getCumulativeReceivable() {
        return cumulativeReceivable;
    }

    public void setCumulativeReceivable(BigDecimal cumulativeReceivable) {
        this.cumulativeReceivable = cumulativeReceivable;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 期号
     */
    public java.lang.String getIssueNumber() {
        return issueNumber;
    }

    /**
     * 期号
     */
    public void setIssueNumber(java.lang.String issueNumber) {
        this.issueNumber = issueNumber;
    }
    /**
     * 完成工程款月份
     */
    public java.lang.String getCompletionMonth() {
        return completionMonth;
    }

    /**
     * 完成工程款月份
     */
    public void setCompletionMonth(java.lang.String completionMonth) {
        this.completionMonth = completionMonth;
    }
    /**
     * 申请单编号
     */
    public java.lang.String getApplicationNo() {
        return applicationNo;
    }

    /**
     * 申请单编号
     */
    public void setApplicationNo(java.lang.String applicationNo) {
        this.applicationNo = applicationNo;
    }
    /**
     * 申请金额(元)
     */
    public java.math.BigDecimal getApplicationAmount() {
        return applicationAmount;
    }

    /**
     * 申请金额(元)
     */
    public void setApplicationAmount(java.math.BigDecimal applicationAmount) {
        this.applicationAmount = applicationAmount;
    }
    /**
     * 本期
     */
    public java.math.BigDecimal getCurrentApproval() {
        return currentApproval;
    }

    /**
     * 本期
     */
    public void setCurrentApproval(java.math.BigDecimal currentApproval) {
        this.currentApproval = currentApproval;
    }
    /**
     * 累计
     */
    public java.math.BigDecimal getCumulativeApproval() {
        return cumulativeApproval;
    }

    /**
     * 累计
     */
    public void setCumulativeApproval(java.math.BigDecimal cumulativeApproval) {
        this.cumulativeApproval = cumulativeApproval;
    }
    /**
     * 本期
     */
    public java.math.BigDecimal getCurrentRetention() {
        return currentRetention;
    }

    /**
     * 本期
     */
    public void setCurrentRetention(java.math.BigDecimal currentRetention) {
        this.currentRetention = currentRetention;
    }
    /**
     * 累计
     */
    public java.math.BigDecimal getCumulativeRetention() {
        return cumulativeRetention;
    }

    /**
     * 累计
     */
    public void setCumulativeRetention(java.math.BigDecimal cumulativeRetention) {
        this.cumulativeRetention = cumulativeRetention;
    }
    /**
     * 本期
     */
    public java.math.BigDecimal getCurrentActual() {
        return currentActual;
    }

    /**
     * 本期
     */
    public void setCurrentActual(java.math.BigDecimal currentActual) {
        this.currentActual = currentActual;
    }
    /**
     * 累计
     */
    public java.math.BigDecimal getCumulativeActual() {
        return cumulativeActual;
    }

    /**
     * 累计
     */
    public void setCumulativeActual(java.math.BigDecimal cumulativeActual) {
        this.cumulativeActual = cumulativeActual;
    }
    /**
     * 本期
     */
    public java.math.BigDecimal getCurrentUncollected() {
        return currentUncollected;
    }

    /**
     * 本期
     */
    public void setCurrentUncollected(java.math.BigDecimal currentUncollected) {
        this.currentUncollected = currentUncollected;
    }
    /**
     * 累计
     */
    public java.math.BigDecimal getCumulativeUncollected() {
        return cumulativeUncollected;
    }

    /**
     * 累计
     */
    public void setCumulativeUncollected(java.math.BigDecimal cumulativeUncollected) {
        this.cumulativeUncollected = cumulativeUncollected;
    }
    /**
     * 实际收款日期
     */
    public java.util.Date getActualCollection() {
        return actualCollection;
    }

    /**
     * 实际收款日期
     */
    public void setActualCollection(java.util.Date actualCollection) {
        this.actualCollection = actualCollection;
    }
    /**
     * 现金流
     */
    public java.lang.String getCashFlow() {
        return cashFlow;
    }

    /**
     * 现金流
     */
    public void setCashFlow(java.lang.String cashFlow) {
        this.cashFlow = cashFlow;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 财务列报收入
     */
    public java.math.BigDecimal getIncome() {
        return income;
    }

    /**
     * 财务列报收入
     */
    public void setIncome(java.math.BigDecimal income) {
        this.income = income;
    }
    
}

==> ejc-middlemeasurement-impl-3.0.0-20220428.022448-70-sources.jar: com/ejianc/business/middlemeasurement/bean/InterimsettlementdetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目期中结算台账子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_interimsettlementdetail")
public class InterimsettlementdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="Issue_number")
    private java.lang.String issueNumber; // 期号
    @TableField(value="completion_month")
    private java.lang.String completionMonth; // 完成工程款月份
    @TableField(value="application_no")
    private java.lang.String applicationNo; // 申请单编号
    @TableField(value="application_amount")
    private java.math.BigDecimal applicationAmount; // 申请金额(元)
    @TableField(value="current_approval")
    private java.math.BigDecimal currentApproval; // 本期
    @TableField(value="cumulative_approval")
    private java.math.BigDecimal cumulativeApproval; // 累计
    @TableField(value="income")
    private java.math.BigDecimal income; // 财务列报收入
    @TableField(value="current_receivable")
    private java.math.BigDecimal currentReceivable; // 本期
    @TableField(value="cumulative_receivable")
    private java.math.BigDecimal cumulativeReceivable; // 累计
    @TableField(value="current_retention")
    private java.math.BigDecimal currentRetention; // 本期
    @TableField(value="cumulative_retention")
    private java.math.BigDecimal cumulativeRetention; // 累计
    @TableField(value="current_actual")
    private java.math.BigDecimal currentActual; // 本期
    @TableField(value="cumulative_actual")
    private java.math.BigDecimal cumulativeActual; // 累计
    @TableField(value="current_uncollected")
    private java.math.BigDecimal currentUncollected; // 本期
    @TableField(value="cumulative_uncollected")
    private java.math.BigDecimal cumulativeUncollected; // 累计
    @TableField(value="actual_collection")
    private java.util.Date actualCollection; // 实际收款日期
    @TableField(value="cash_flow")
    private java.lang.String cashFlow; // 现金流
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="past_flag")
    private java.lang.Integer pastFlag;//是否为往期数据：1是，0否



    public BigDecimal getCurrentReceivable() {
        return currentReceivable;
    }

    public void setCurrentReceivable(BigDecimal currentReceivable) {
        this.currentReceivable = currentReceivable;
    }

    public BigDecimal getCumulativeReceivable() {
        return cumulativeReceivable;
    }

    public void setCumulativeReceivable(BigDecimal cumulativeReceivable) {
        this.cumulativeReceivable = cumulativeReceivable;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 期号
     */
    public java.lang.String getIssueNumber() {
        return issueNumber;
    }

    /**
     * 期号
     */
    public void setIssueNumber(java.lang.String issueNumber) {
        this.issueNumber = issueNumber;
    }
    /**
     * 完成工程款月份
     */
    public java.lang.String getCompletionMonth() {
        return completionMonth;
    }

    /**
     * 完成工程款月份
     */
    public void setCompletionMonth(java.lang.String completionMonth) {
        this.completionMonth = completionMonth;
    }
    /**
     * 申请单编号
     */
    public java.lang.String getApplicationNo() {
        return applicationNo;
    }

    /**
     * 申请单编号
     */
    public void setApplicationNo(java.lang.String applicationNo) {
        this.applicationNo = applicationNo;
    }
    /**
     * 申请金额(元)
     */
    public java.math.BigDecimal getApplicationAmount() {
        return applicationAmount;
    }

    /**
     * 申请金额(元)
     */
    public void setApplicationAmount(java.math.BigDecimal applicationAmount) {
        this.applicationAmount = applicationAmount;
    }
    /**
     * 本期
     */
    public java.math.BigDecimal getCurrentApproval() {
        return currentApproval;
    }

    /**
     * 本期
     */
    public void setCurrentApproval(java.math.BigDecimal currentApproval) {
        this.currentApproval = currentApproval;
    }
    /**
     * 累计
     */
    public java.math.BigDecimal getCumulativeApproval() {
        return cumulativeApproval;
    }

    /**
     * 累计
     */
    public void setCumulativeApproval(java.math.BigDecimal cumulativeApproval) {
        this.cumulativeApproval = cumulativeApproval;
    }
    /**
     * 本期
     */
    public java.math.BigDecimal getCurrentRetention() {
        return currentRetention;
    }

    /**
     * 本期
     */
    public void setCurrentRetention(java.math.BigDecimal currentRetention) {
        this.currentRetention = currentRetention;
    }
    /**
     * 累计
     */
    public java.math.BigDecimal getCumulativeRetention() {
        return cumulativeRetention;
    }

    /**
     * 累计
     */
    public void setCumulativeRetention(java.math.BigDecimal cumulativeRetention) {
        this.cumulativeRetention = cumulativeRetention;
    }
    /**
     * 本期
     */
    public java.math.BigDecimal getCurrentActual() {
        return currentActual;
    }

    /**
     * 本期
     */
    public void setCurrentActual(java.math.BigDecimal currentActual) {
        this.currentActual = currentActual;
    }
    /**
     * 累计
     */
    public java.math.BigDecimal getCumulativeActual() {
        return cumulativeActual;
    }

    /**
     * 累计
     */
    public void setCumulativeActual(java.math.BigDecimal cumulativeActual) {
        this.cumulativeActual = cumulativeActual;
    }
    /**
     * 本期
     */
    public java.math.BigDecimal getCurrentUncollected() {
        return currentUncollected;
    }

    /**
     * 本期
     */
    public void setCurrentUncollected(java.math.BigDecimal currentUncollected) {
        this.currentUncollected = currentUncollected;
    }
    /**
     * 累计
     */
    public java.math.BigDecimal getCumulativeUncollected() {
        return cumulativeUncollected;
    }

    /**
     * 累计
     */
    public void setCumulativeUncollected(java.math.BigDecimal cumulativeUncollected) {
        this.cumulativeUncollected = cumulativeUncollected;
    }
    /**
     * 实际收款日期
     */
    public java.util.Date getActualCollection() {
        return actualCollection;
    }

    /**
     * 实际收款日期
     */
    public void setActualCollection(java.util.Date actualCollection) {
        this.actualCollection = actualCollection;
    }
    /**
     * 现金流
     */
    public java.lang.String getCashFlow() {
        return cashFlow;
    }

    /**
     * 现金流
     */
    public void setCashFlow(java.lang.String cashFlow) {
        this.cashFlow = cashFlow;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 财务列报收入
     */
    public java.math.BigDecimal getIncome() {
        return income;
    }

    /**
     * 财务列报收入
     */
    public void setIncome(java.math.BigDecimal income) {
        this.income = income;
    }

    public Integer getPastFlag() {
        return pastFlag;
    }

    public void setPastFlag(Integer pastFlag) {
        this.pastFlag = pastFlag;
    }
}
